# Jumbo.com API
Unofficial Python wrapper for the Jumbo.com API, a way to view your orders, time slots and basket information
Use the same credentials as the ones you use for the app or website.

This library is not affiliated with Jumbo and retrieves data from the endpoints of the mobile application. Use at your own risk.

## Changelog
See the [changelog](CHANGELOG.md) for more information.

## Home Assistant
This library is being used in Home Assistant as a [custom component](https://github.com/peternijssen/home-asssistant-jumbo).

## Contributors
* [Peter Nijssen](https://github.com/peternijssen)
* [Rolf Berkenbosch](https://github.com/rolfberkenbosch)
